/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { Injectable } from '@angular/core';
import {Observable} from "rxjs";
import {HttpClient} from "@angular/common/http";
import {JsonObject} from "@angular/compiler-cli/ngcc/src/packages/entry_point";

@Injectable({
  providedIn: 'root'
})
export class CapabilitiesService {

  constructor(
    private httpClient: HttpClient,
  ) { }

  /**
   * Gets JSON list of the names of enabled capabilities
   * @return Observable<JsonObject>
   */
  public getEnabledCapabilities(): Observable<JsonObject> {
    const url = `capabilities`;
    return this.httpClient.get<JsonObject>(url);
  }

  /**
   * Gets list of available staff for QA assignment
   * @param group  Group of staff members
   */
  public getQaStaff(group: string): Observable<any> {
    const url = `/capabilities/available_qa_staff?group=${group}`;
    return this.httpClient.get<JsonObject>(url);
  }

  /**
   * Get the workspaces-analyst email address from the capo setting.
   * @return Observable<CapabilityVersion>  Result of REST call to get the email address
   */
  public getAnalystEmail(): Observable<string> {
    const url = `/capabilities/analyst_email`;
    return this.httpClient.get<string>(url);
  }
}
