# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""fix std_calibration env

Revision ID: 69c10adfb322
Revises: b9945cdb3b1e
Create Date: 2021-06-02 14:56:07.681712

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "69c10adfb322"
down_revision = "b9945cdb3b1e"
branch_labels = None
depends_on = None


def upgrade():
    op.execute(
        """
        UPDATE workflow_templates
        SET content=E'executable = std_calibration.sh
arguments = {{product_locator}} {{request_id}} metadata.json PPR.xml

output = calibration.out
error = calibration.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/deliver-cipl.sh, ./PPR.xml, ./metadata.json
transfer_output_files = working, rawdata, products

request_memory = 48G
getenv = True
environment = "CAPO_PATH=/home/casa/capo HOME=/users/vlapipe"

queue
'
        WHERE filename='std_calibration.condor' and workflow_name='std_calibration'
        """
    )


def downgrade():
    op.execute(
        """
        UPDATE workflow_templates
        SET content=E'executable = std_calibration.sh
arguments = {{product_locator}} {{request_id}} metadata.json PPR.xml

output = calibration.out
error = calibration.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/deliver-cipl.sh, ./PPR.xml, ./metadata.json
transfer_output_files = working, rawdata, products

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue
'
        WHERE filename='std_calibration.condor' and workflow_name='std_calibration'
        """
    )
